pytest-8.3.4
=======================================

pytest 8.3.4 has just been released to PyPI.

This is a bug-fix release, being a drop-in replacement. To upgrade::

  pip install --upgrade pytest

The full changelog is available at https://docs.pytest.org/en/stable/changelog.html.

Thanks to all of the contributors to this release:

* Bruno Oliveira
* Freya Bruhin
* Frank Hoffmann
* Jakob van Santen
* Leonardus Chen
* Pierre Sassoulas
* Pradeep Kumar
* Ran Benita
* Serge Smertin
* Stefaan Lippens
* Sviatoslav Sydorenko (Святослав Сидоренко)
* dongfangtianyu
* suspe


Happy testing,
The pytest Development Team
